(function () {
    'use strict';

    var handleDOMContentLoaded = function DOMContentLoadedEventHandler() {
        var TextField = function textFieldConstructor(id) {
            this.id = id;
            this.textFieldNode = document.querySelector('[data-md-id="' + id + '"]');
            this.formControlNode = this.textFieldNode.querySelector('.md-form-control');
            this.textFieldInputNode = this.textFieldNode.querySelector('.md-input-holder__input');
            this.helperTextNode = this.textFieldNode.querySelector('.md-helper-text');
            this.value = this.textFieldInputNode.value;

            var that = this;
            var formControlNode = this.formControlNode;
            function checkInputFilledStatus() {
                if (that.value !== '') {
                    formControlNode.classList.add('md-form-control--filled');
                } else {
                    formControlNode.classList.remove('md-form-control--filled');
                }
            }

            checkInputFilledStatus();

            this.textFieldInputNode.addEventListener('focus', function focusHandler() {
                formControlNode.classList.add('md-form-control--focussed');
                checkInputFilledStatus();
            });
            this.textFieldInputNode.addEventListener('blur', function blurHandler() {
                formControlNode.classList.remove('md-form-control--focussed');
                checkInputFilledStatus();
            });
            this.textFieldInputNode.addEventListener('input', function inputHandler(event) {
                that.value = event.target.value;
                checkInputFilledStatus();
            });
            this.textFieldInputNode.addEventListener('change', function inputHandler(event) {
            	checkInputFilledStatus();
            	});
            // We attach an empty animation to input field from css when chrome autofills it 
            // using -webkit-autofill pseudo class.
            // This enables us to listen to animationstart event which is fired when autofill happens.
            //  We then attach a filled class to float the label up.
            this.textFieldInputNode.addEventListener('animationstart', function(event) {
            	//console.log('val', event.target.value);
            	//checkInputFilledStatus();
            	formControlNode.classList.add('md-form-control--filled');
            });
        };

        TextField.prototype.setHelperText = function setHelperText(text) {
            this.helperTextNode.textContent = text;
        };

        TextField.prototype.setError = function setErrorText(text) {
            if (text !== undefined) {
                this.setHelperText(text);
            }
            this.formControlNode.classList.add('md-form-control--error');
        };

        TextField.prototype.clearError = function removeErrorClass() {
            this.formControlNode.classList.remove('md-form-control--error');
        }

        TextField.prototype.addEventListener = function addEventListener(eventType, handler) {
            this.textFieldInputNode.addEventListener(eventType, handler, false);
        }

        var globalNS = (function () {
            // the only reliable means to get the global object is
            // `Function('return this')()`
            // However, this causes CSP violations in Chrome apps.
            if (typeof self !== 'undefined') {
                return self;
            }

            if (typeof window !== 'undefined') {
                return window;
            }

            if (typeof global !== 'undefined') {
                return global;
            }

            throw new Error('unable to locate global object');
        }());

        globalNS.MDComponents = {
            TextField: TextField
        };
    };

    document.addEventListener('DOMContentLoaded', handleDOMContentLoaded, false);
}())